==> nextcloud-28.0.3.tgz: nextcloud/apps/sharebymail/l10n/he.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "משותף עם {email}",
    "Shared with {email} by {actor}" : "שותף עם {email} על ידי {actor}",
    "Unshared from {email}" : "השיתוף עם {email} בוטל",
    "Unshared from {email} by {actor}" : "השיתוף עם {email} בוטל על ידי {actor}",
    "Password for mail share sent to {email}" : "ססמת השיתוף בדוא״ל נשלחה אל {email}",
    "Password for mail share sent to you" : "ססמת השיתוף בדוא״ל נשלחה אליך",
    "You shared {file} with {email} by mail" : "שיתפת את {file} עם {email} בדוא״ל",
    "{actor} shared {file} with {email} by mail" : "{file} שותף עם {email} בדוא״ל על ידי {actor}",
    "You unshared {file} from {email} by mail" : "ביטלת את השיתוף של {file} מפני {email} בדוא״ל",
    "{actor} unshared {file} from {email} by mail" : "{actor} ביטל שיתוף {file} מ- {email} בדואר",
    "Password to access {file} was sent to {email}" : "ססמת הגישה אל {file} נשלחה אל {email}",
    "Password to access {file} was sent to you" : "ססמת הגישה אל {file} נשלחה אליך",
    "Share by mail" : "שיתוף בדוא״ל",
    "Failed to send share by email" : "שליחת השיתוף בדוא״ל נכשלה",
    "%1$s shared »%2$s« with you" : "„%2$s” שותף אתך על ידי %1$s",
    "%1$s shared »%2$s« with you." : "„%2$s” שותף אתך על ידי %1$s.",
    "Click the button below to open it." : "יש ללחוץ על הכפתור שלהלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$sשיתף »%2$s« איתך.\nהיית אמור לקבל כבר דואר נפרד, עם קישור לגישה אליו.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s שיתף »%2$s« איתף. היית אמור לקבל כבר דואר נפרד, עם קישור לגישה אליו.",
    "Password to access »%1$s« shared to you by %2$s" : "סיסמא לגישה ל-»%1$s« משותף לך על ידי %2$s",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s שיתף » %2$s« איתך, ורוצה להוסיף:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$sשיתף »%2$s« איתך, ורוצה להוסיף:",
    "»%s« added a note to a file shared with you" : "התווספה הערה על קובץ ששותף את על ידי „%s”",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "כרגע שיתפת את »%1$s« עם %2$s. השיתוף כבר נשלח לנמען. בשל מדיניות האבטחה שהגדיר מנהל המערכת של %3$s, יש להגן כל שיתוף על ידי סיסמה, ואינו רשאי לשלוח את הסיסמה ישירות לנמען. לכן, עליך להעביר את הסיסמה באופן ידני לנמען.",
    "Password to access »%1$s« shared by you with %2$s" : "ססמה לגשת אל „%1$s” ששותף על ידיך עם %2$s",
    "This is the password:" : "זו הססמה:",
    "You can choose a different password at any time in the share dialog." : "ניתן לבחור בססמה אחרת בכל עת בתיבת דו־שיח השיתוף.",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "Share provider which allows you to share files by mail" : "ספק השיתוף שמאפשר לך לשתף קבצים בדוא״ל",
    "Send password by mail" : "שליחת ססמה בדוא״ל",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "מאפשר למשתמשים לשתף קישורים מותאמים אישית לקובץ או לתיקייה על ידי הקלדת כתובת דוא״ל."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-31.0.12.tgz: nextcloud/apps/sharebymail/l10n/he.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "משותף עם {email}",
    "Shared with {email} by {actor}" : "שותף עם {email} על ידי {actor}",
    "Unshared from {email}" : "השיתוף עם {email} בוטל",
    "Unshared from {email} by {actor}" : "השיתוף עם {email} בוטל על ידי {actor}",
    "Password for mail share sent to {email}" : "ססמת השיתוף בדוא״ל נשלחה אל {email}",
    "Password for mail share sent to you" : "ססמת השיתוף בדוא״ל נשלחה אליך",
    "You shared {file} with {email} by mail" : "שיתפת את {file} עם {email} בדוא״ל",
    "{actor} shared {file} with {email} by mail" : "{file} שותף עם {email} בדוא״ל על ידי {actor}",
    "You unshared {file} from {email} by mail" : "ביטלת את השיתוף של {file} מפני {email} בדוא״ל",
    "{actor} unshared {file} from {email} by mail" : "{actor} ביטל שיתוף {file} מ- {email} בדואר",
    "Password to access {file} was sent to {email}" : "ססמת הגישה אל {file} נשלחה אל {email}",
    "Password to access {file} was sent to you" : "ססמת הגישה אל {file} נשלחה אליך",
    "Share by mail" : "שיתוף בדוא״ל",
    "Failed to send share by email" : "שליחת השיתוף בדוא״ל נכשלה",
    "Note:" : "הערה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "This is the password:" : "זו הססמה:",
    "You can choose a different password at any time in the share dialog." : "ניתן לבחור בססמה אחרת בכל עת בתיבת דו־שיח השיתוף.",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "Share provider which allows you to share files by mail" : "ספק השיתוף שמאפשר לך לשתף קבצים בדוא״ל",
    "Send password by mail" : "שליחת ססמה בדוא״ל"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
